@@ -1,6 +1,6 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
  * Realized in co-operation between Siemens AG
  * and University of Essen, Institute of Computer Networking Technology.
@@ -64,6 +64,7 @@ static void asapInstanceHandleRegistrarTimeout(struct Dispatcher* dispatcher,
 
 /* ###### Constructor #################################################### */
 struct ASAPInstance* asapInstanceNew(struct Dispatcher*          dispatcher,
+                                     const bool                  enableAutoConfig,
                                      const union sockaddr_union* registrarAnnounceAddress,
                                      struct TagItem*             tags)
 {
@@ -116,7 +117,9 @@ struct ASAPInstance* asapInstanceNew(struct Dispatcher*          dispatcher,
          }
 
          /* ====== Initialize registrar table ============================ */
-         asapInstance->RegistrarSet = registrarTableNew(asapInstance->StateMachine, registrarAnnounceAddress, tags);
+         asapInstance->RegistrarSet = registrarTableNew(asapInstance->StateMachine,
+                                                        enableAutoConfig,
+                                                        registrarAnnounceAddress, tags);
          if(asapInstance->RegistrarSet == NULL) {
             asapInstanceDelete(asapInstance);
             return(NULL);
@@ -943,7 +946,7 @@ static void asapInstanceHandleEndpointKeepAlive(
    if(fd == asapInstance->RegistrarHuntSocket) {
       if(message->Flags & AHF_ENDPOINT_KEEP_ALIVE_HOME) {
          LOG_NOTE
-         fprintf(stdlog, "EndpointKeepAlive from $%08x (assoc %u) instead of home-registrar assoc $%08x -> replacing home registrar\n",
+         fprintf(stdlog, "EndpointKeepAlive from $%08x (assoc %u) instead of home registrar assoc $%08x -> replacing home registrar\n",
                message->RegistrarIdentifier,
                (unsigned int)message->AssocID,
                asapInstance->RegistrarIdentifier);
@@ -968,7 +971,7 @@ static void asapInstanceHandleEndpointKeepAlive(
       }
       else {
          LOG_WARNING
-         fprintf(stdlog, "EndpointKeepAlive from $%08x (assoc %u) instead of home-registrar assoc $%08x. The H bit is not set, therefore ignoring it.",
+         fprintf(stdlog, "EndpointKeepAlive from $%08x (assoc %u) instead of home-registrar assoc $%08x. The H bit is not set, therefore ignoring it.\n",
                message->RegistrarIdentifier,
                (unsigned int)message->AssocID,
                asapInstance->RegistrarIdentifier);
@@ -978,6 +981,9 @@ static void asapInstanceHandleEndpointKeepAlive(
    else {
       if(asapInstance->RegistrarIdentifier == UNDEFINED_REGISTRAR_IDENTIFIER) {
          asapInstance->RegistrarIdentifier = message->RegistrarIdentifier;
+         LOG_NOTE
+         fprintf(stdlog, "Home registrar is $%08x\n", asapInstance->RegistrarIdentifier);
+         LOG_END
       }
    }
 
@@ -1140,7 +1146,7 @@ static void asapInstanceHandleRegistrarConnectionEvent(
 
    dispatcherLock(asapInstance->StateMachine);
 
-   LOG_VERBOSE
+   LOG_VERBOSE2
    fputs("Entering Connection Handler...\n", stdlog);
    LOG_END
 
@@ -1155,6 +1161,7 @@ static void asapInstanceHandleRegistrarConnectionEvent(
       LOG_ERROR
       fprintf(stdlog, "Event for unknown socket %d\n", fd);
       LOG_END_FATAL
+      return;   /* Avoids warning about uninitializes message buffer. */
    }
 
    flags               = 0;
@@ -1355,8 +1362,9 @@ static void* asapInstanceMainLoop(void* args)
       dispatcherGetPollParameters(asapInstance->StateMachine,
                                   (struct pollfd*)&ufds, &nfds, &timeout, &pollTimeStamp);
       pipeIndex = nfds;
-      ufds[pipeIndex].fd     = asapInstance->MainLoopPipe[0];
-      ufds[pipeIndex].events = POLLIN;
+      ufds[pipeIndex].fd      = asapInstance->MainLoopPipe[0];
+      ufds[pipeIndex].events  = POLLIN;
+      ufds[pipeIndex].revents = 0;
       if((struct ASAPInterThreadMessage*)interThreadMessagePortGetFirstMessage(&asapInstance->MainLoopPort) !=
             asapInstance->LastAITM) {
          /* There are new AITM messages to be handled.
