@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: messagebuffer.c 1181 2006-08-04 02:19:39Z dreibh $
+ * $Id: messagebuffer.c 1335 2007-02-13 12:32:36Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -76,7 +76,7 @@ ssize_t messageBufferRead(struct MessageBuffer*    messageBuffer,
 
    LOG_VERBOSE4
    fprintf(stdlog, "Reading into message buffer from socket %d: offset=%u, max=%u\n",
-           sockfd, messageBuffer->BufferPos, messageBuffer->BufferSize);
+           sockfd, (unsigned int)messageBuffer->BufferPos, (unsigned int)messageBuffer->BufferSize);
    LOG_END
    result = recvfromplus(sockfd,
                          (char*)&messageBuffer->Buffer[messageBuffer->BufferPos],
@@ -84,7 +84,7 @@ ssize_t messageBufferRead(struct MessageBuffer*    messageBuffer,
                          flags, from, fromlen, ppid, assocID, streamID, timeout);
    LOG_VERBOSE4
    fprintf(stdlog, "Read result for socket %d is %d, EOR=%s, NOTIFICATION=%s, useEOR=%s\n",
-           sockfd, result,
+           sockfd, (int)result,
            (*flags & MSG_EOR) ? "yes" : "no",
            (*flags & MSG_NOTIFICATION) ? "yes" : "no",
            (messageBuffer->UseEOR == true) ? "yes" : "no");
@@ -93,14 +93,14 @@ ssize_t messageBufferRead(struct MessageBuffer*    messageBuffer,
       messageBuffer->BufferPos += (size_t)result;
       if( (messageBuffer->UseEOR) && (!(*flags & MSG_EOR)) ) {
          LOG_VERBOSE4
-         fprintf(stdlog, "Partially read %d bytes on socket %d\n", result, sockfd);
+         fprintf(stdlog, "Partially read %d bytes on socket %d\n", (int)result, sockfd);
          LOG_END
          result = MBRead_Partial;
       }
       else {
          LOG_VERBOSE4
          fprintf(stdlog, "Partially read %d bytes on socket %d, message of %u bytes completed\n",
-                 result, sockfd, messageBuffer->BufferPos);
+                 (int)result, sockfd, (int)messageBuffer->BufferPos);
          LOG_END
          /*
          LOG_VERBOSE5
