@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: netdouble.c 975 2006-03-01 21:11:38Z dreibh $
+ * $Id: netdouble.c 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -157,18 +157,26 @@ double networkToDouble(network_double_t value)
 
 #else
 
+union DoubleIntUnion
+{
+   double             Double;
+   unsigned long long Integer;
+};
+
 /* ###### Convert double to machine-independent form ##################### */
 network_double_t doubleToNetwork(const double d)
 {
-   const unsigned long long* v = (const unsigned long long*)&d;
-   return(hton64(*v));
+   union DoubleIntUnion valueUnion;
+   valueUnion.Double = d;
+   return(hton64(valueUnion.Integer));
 }
 
 /* ###### Convert machine-independent form to double ##################### */
 double networkToDouble(network_double_t value)
 {
-   unsigned long long w = ntoh64(value);
-   return(*((double*)&w));
+   union DoubleIntUnion valueUnion;
+   valueUnion.Integer = ntoh64(value);
+   return(valueUnion.Double);
 }
 
 #endif
