@@ -1,5 +1,5 @@
 /*
- *  $Id: netutilities.c 1181 2006-08-04 02:19:39Z dreibh $
+ *  $Id: netutilities.c 1231 2006-12-22 15:26:06Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -1938,7 +1938,7 @@ bool tuneSCTP(int sockfd, sctp_assoc_t assocID, struct TagItem* tags)
    struct sctp_rtoinfo     rtoinfo;
    struct sctp_paddrparams peerParams;
    struct sctp_assocparams assocParams;
-   union sockaddr_union*   addrs;
+   union sockaddr_union*   addrs = NULL;
    socklen_t               size;
    int                     i, n;
    bool                    result = true;
