@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: peerlistnode-template_impl.h 704 2006-02-22 09:04:55Z dreibh $
+ * $Id: peerlistnode-template_impl.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  */
 
 /* ###### Print ########################################################## */
-void ST_CLASS(peerListIndexStorageNodePrint)(const void *nodePtr, FILE* fd)
+void ST_CLASS(peerListIndexStorageNodePrint)(const void* nodePtr, FILE* fd)
 {
    const struct ST_CLASS(PeerListNode)* peerListNode = (struct ST_CLASS(PeerListNode)*)nodePtr;
    ST_CLASS(peerListNodePrint)(peerListNode, fd, 0);
@@ -68,8 +68,8 @@ void ST_CLASS(peerListTimerStorageNodePrint)(const void* nodePtr, FILE* fd)
 
 
 /* ###### Comparison ##################################################### */
-int ST_CLASS(peerListTimerStorageNodeComparison)(const void *nodePtr1,
-                                                 const void *nodePtr2)
+int ST_CLASS(peerListTimerStorageNodeComparison)(const void* nodePtr1,
+                                                 const void* nodePtr2)
 {
    const struct ST_CLASS(PeerListNode)* node1 =
       ST_CLASS(getPeerListNodeFromPeerListTimerStorageNode)((void*)nodePtr1);
@@ -102,6 +102,10 @@ void ST_CLASS(peerListNodeNew)(struct ST_CLASS(PeerListNode)* peerListNode,
    peerListNode->Flags               = flags;
    peerListNode->OwnershipChecksum   = INITIAL_HANDLESPACE_CHECKSUM;
 
+   peerListNode->Status              = 0;
+   peerListNode->TakeoverRegistrarID = UNDEFINED_REGISTRAR_IDENTIFIER;
+   peerListNode->TakeoverProcess     = NULL;
+
    peerListNode->LastUpdateTimeStamp = 0;
    peerListNode->TimerCode           = 0;
    peerListNode->TimerTimeStamp      = 0;
@@ -188,6 +192,22 @@ void ST_CLASS(peerListNodeGetDescription)(
       safestrcat(buffer, "+multicast", bufferSize);
    }
 
+   if(peerListNode->Status & PLNS_LISTSYNC) {
+      safestrcat(buffer, " LISTSYNC", bufferSize);
+   }
+   if(peerListNode->Status & PLNS_HTSYNC) {
+      safestrcat(buffer, " HTSYNC", bufferSize);
+   }
+   if(peerListNode->Status & PLNS_MENTOR) {
+      safestrcat(buffer, " MENTOR", bufferSize);
+   }
+   if(peerListNode->TakeoverProcess) {
+      safestrcat(buffer, " TAKEOVER(own)", bufferSize);
+   }
+   if(peerListNode->TakeoverRegistrarID) {
+      safestrcat(buffer, " TAKEOVER(other)", bufferSize);
+   }
+
    if((fields & PLNPO_TRANSPORT) &&
       (peerListNode->AddressBlock->Addresses > 0)) {
       transportAddressBlockGetDescription(peerListNode->AddressBlock,
