@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolhandlespacemanagement-template.h 1078 2006-04-13 08:13:02Z dreibh $
+ * $Id: poolhandlespacemanagement-template.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -80,6 +80,8 @@ size_t ST_CLASS(poolHandlespaceManagementGetPools)(
           const struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement);
 size_t ST_CLASS(poolHandlespaceManagementGetPoolElements)(
           const struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement);
+size_t ST_CLASS(poolHandlespaceManagementGetOwnedPoolElements)(
+          const struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement);
 size_t ST_CLASS(poolHandlespaceManagementGetPoolElementsOfPool)(
           struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
           const struct PoolHandle*                    poolHandle);
@@ -169,6 +171,14 @@ int ST_CLASS(poolHandlespaceManagementGetHandleTable)(
        size_t                                      maxElements);
 
 
+void ST_CLASS(poolHandlespaceManagementMarkPoolElementNodes)(
+        struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
+        const RegistrarIdentifierType ownerID);
+size_t ST_CLASS(poolHandlespaceManagementPurgeMarkedPoolElementNodes)(
+          struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
+          const RegistrarIdentifierType ownerID);
+
+
 #ifdef __cplusplus
 }
 #endif
