@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolhandlespacemanagement-template_impl.h 1091 2006-05-09 08:48:20Z dreibh $
+ * $Id: poolhandlespacemanagement-template_impl.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -307,6 +307,14 @@ size_t ST_CLASS(poolHandlespaceManagementGetPoolElements)(
 }
 
 
+/* ###### Get number of owned pool elements ############################## */
+size_t ST_CLASS(poolHandlespaceManagementGetOwnedPoolElements)(
+          const struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement)
+{
+   return(ST_CLASS(poolHandlespaceNodeGetOwnedPoolElementNodes)(&poolHandlespaceManagement->Handlespace));
+}
+
+
 /* ###### Get number of pool elements of given pool ###################### */
 size_t ST_CLASS(poolHandlespaceManagementGetPoolElementsOfPool)(
           struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
@@ -681,3 +689,47 @@ size_t ST_CLASS(poolHandlespaceManagementPurgeExpiredPoolElements)(
 
    return(purgedPoolElements);
 }
+
+
+/* ###### Mark pool element nodes owned by given PR ###################### */
+void ST_CLASS(poolHandlespaceManagementMarkPoolElementNodes)(
+        struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
+        const RegistrarIdentifierType ownerID)
+{
+   struct ST_CLASS(PoolElementNode)* poolElementNode;
+   struct ST_CLASS(PoolElementNode)* nextPoolElementNode;
+
+   poolElementNode = ST_CLASS(poolHandlespaceNodeGetFirstPoolElementOwnershipNodeForIdentifier)(
+                        &poolHandlespaceManagement->Handlespace, ownerID);
+   while(poolElementNode) {
+      nextPoolElementNode = ST_CLASS(poolHandlespaceNodeGetNextPoolElementOwnershipNodeForSameIdentifier)(
+                               &poolHandlespaceManagement->Handlespace, poolElementNode);
+      poolElementNode->Flags |= PENF_MARKED;
+      poolElementNode = nextPoolElementNode;
+   }
+}
+
+
+/* ###### Purge marked pool element nodes owned by given PR ############## */
+size_t ST_CLASS(poolHandlespaceManagementPurgeMarkedPoolElementNodes)(
+          struct ST_CLASS(PoolHandlespaceManagement)* poolHandlespaceManagement,
+          const RegistrarIdentifierType ownerID)
+{
+   struct ST_CLASS(PoolElementNode)* poolElementNode;
+   struct ST_CLASS(PoolElementNode)* nextPoolElementNode;
+   size_t                            count = 0;
+
+   poolElementNode = ST_CLASS(poolHandlespaceNodeGetFirstPoolElementOwnershipNodeForIdentifier)(
+                        &poolHandlespaceManagement->Handlespace, ownerID);
+   while(poolElementNode) {
+      nextPoolElementNode = ST_CLASS(poolHandlespaceNodeGetNextPoolElementOwnershipNodeForSameIdentifier)(
+                               &poolHandlespaceManagement->Handlespace, poolElementNode);
+      if(poolElementNode->Flags & PENF_MARKED) {
+         CHECK(ST_CLASS(poolHandlespaceManagementDeregisterPoolElementByPtr)(
+                  poolHandlespaceManagement, poolElementNode) == RSPERR_OKAY);
+         count++;
+      }
+      poolElementNode = nextPoolElementNode;
+   }
+   return(count);
+}
