@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolhandlespacenode-template.h 1022 2006-03-16 09:00:38Z dreibh $
+ * $Id: poolhandlespacenode-template.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ struct ST_CLASS(PoolHandlespaceNode)
    HandlespaceChecksumAccumulatorType  OwnershipChecksum;            /* Ownership checksum             */
    RegistrarIdentifierType             HomeRegistrarIdentifier;      /* This NS's Identifier           */
    size_t                              PoolElements;                 /* Number of Pool Elements        */
+   size_t                              OwnedPoolElements;            /* Number of owned Pool Elements  */
 
    void* NotificationUserData;
    void (*PoolNodeUpdateNotification)(struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode,
@@ -128,8 +129,6 @@ size_t ST_CLASS(poolHandlespaceNodeGetConnectionNodesForConnection)(
           const sctp_assoc_t                    assocID);
 struct ST_CLASS(PoolElementNode)* ST_CLASS(poolHandlespaceNodeGetFirstPoolElementConnectionNode)(
                                      struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode);
-struct ST_CLASS(PoolElementNode)* ST_CLASS(poolHandlespaceNodeGetLastPoolElementConnectionNode)(
-                                     struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode);
 struct ST_CLASS(PoolElementNode)* ST_CLASS(poolHandlespaceNodeFindNearestPrevPoolElementConnectionNode)(
                                      struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode,
                                      const int                             connectionSocketDescriptor,
@@ -164,6 +163,8 @@ struct ST_CLASS(PoolElementNode)* ST_CLASS(poolHandlespaceNodeGetNextPoolElement
                                      struct ST_CLASS(PoolElementNode)*     poolElementNode);
 size_t ST_CLASS(poolHandlespaceNodeGetPoolElementNodes)(
           const struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode);
+size_t ST_CLASS(poolHandlespaceNodeGetOwnedPoolElementNodes)(
+          const struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode);
 size_t ST_CLASS(poolHandlespaceNodeGetPoolNodes)(
           const struct ST_CLASS(PoolHandlespaceNode)* poolHandlespaceNode);
 size_t ST_CLASS(poolHandlespaceNodeGetPoolElementNodesOfPool)(
