@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolpolicysettings.h 1142 2006-05-24 13:17:42Z dreibh $
+ * $Id: poolpolicysettings.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,14 +48,6 @@ struct PoolPolicySettings
 };
 
 
-#define PEPS_MIN_WEIGHT                   0
-#define PEPS_MAX_WEIGHT          0xffffffff
-#define PEPS_MIN_LOAD                     0
-#define PEPS_MAX_LOAD              0xffffff
-#define PEPS_MIN_LOADDEGRADATION          0
-#define PEPS_MAX_LOADDEGRADATION   0xffffff
-
-
 void poolPolicySettingsNew(struct PoolPolicySettings* pps);
 void poolPolicySettingsDelete(struct PoolPolicySettings* pps);
 void poolPolicySettingsPrint(const struct PoolPolicySettings* pps,
