@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpool-internals.h 1145 2006-05-24 13:40:33Z dreibh $
+ * $Id: rserpool-internals.h 1288 2007-01-11 20:07:41Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -100,16 +100,6 @@ int rsp_mapsocket(int sd, int toSD);
 int rsp_unmapsocket(int sd);
 
 
-/**
-  * Set session's application status text for rsp_csp_getcomponentstatus().
-  *
-  * @param sd SessionDescriptor.
-  * @param statusText Status text.
-  */
-int rsp_csp_setstatus(int                sd,
-                      rserpool_session_t sessionID,
-                      const char*        statusText);
-
 #ifdef __cplusplus
 }
 #endif
