@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpool.h 1181 2006-08-04 02:19:39Z dreibh $
+ * $Id: rserpool.h 1314 2007-02-03 20:54:55Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,6 +65,7 @@ struct rsp_info
    const char*                ri_build_date;
    const char*                ri_build_time;
    struct rsp_registrar_info* ri_registrars;
+   int                        ri_disable_autoconfig;
    struct sockaddr*           ri_registrar_announce;
 
    uint64_t                   ri_csp_identifier;
@@ -88,6 +89,35 @@ struct rsp_loadinfo
 #define DEREGF_DONTWAIT       (1 << 0)   /* Do not wait for Deregistration Response */
 
 
+/**
+  * Initialize rsp_info structure with defaults.
+  *
+  * @param info rsp_info structure with parameters.
+  */
+void rsp_initinfo(struct rsp_info* info);
+
+/**
+  * Free rsp_info structure contents allocated upon rsp_initarg
+  * calls.
+  *
+  * @param info rsp_info structure with parameters.
+  *
+  * @see rsp_initarg
+  */
+void rsp_freeinfo(struct rsp_info* info);
+
+/**
+  * Handle command line argument and put results into rsp_info structure
+  * (if it is an rsplib parameter).
+  *
+  * @param info rsp_info structure with parameters.
+  * @return 1 in case of success, 0 if the parameter is unknown.
+  *
+  * @see rsp_initarg
+  */
+int rsp_initarg(struct rsp_info* info, const char* arg);
+
+
 /**
   * Initialize the RSerPool library. This function must be called before any
   * other RSerPool library function can be used.
@@ -542,6 +572,15 @@ const char* rsp_getpolicybytype(unsigned int policyType);
   */
 unsigned int rsp_getpolicybyname(const char* policyName);
 
+/**
+  * Set session's application status text for rsp_csp_getcomponentstatus().
+  *
+  * @param sd SessionDescriptor.
+  * @param statusText Status text.
+  */
+int rsp_csp_setstatus(int                sd,
+                      rserpool_session_t sessionID,
+                      const char*        statusText);
 
 #ifdef __cplusplus
 }
