@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: rserpoolerror.h 1181 2006-08-04 02:19:39Z dreibh $
+ * $Id: rserpoolerror.h 1286 2007-01-11 08:24:02Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,10 +42,11 @@ extern "C" {
 #define RSPERR_AUTHORIZATION_FAILURE         0x0003
 #define RSPERR_INVALID_VALUES                0x0004
 #define RSPERR_INCOMPATIBLE_POOL_POLICY      0x0005
-#define RSPERR_OUT_OF_MEMORY                 0x0006
-#define RSPERR_WRONG_PROTOCOL                0x0007
-#define RSPERR_WRONG_CONTROLCHANNEL_HANDLING 0x0008
-#define RSPERR_NOT_FOUND                     0x0009
+#define RSPERR_UNSUPPORTED_POOL_POLICY       0x0006
+#define RSPERR_OUT_OF_MEMORY                 0x0007
+#define RSPERR_WRONG_PROTOCOL                0x0008
+#define RSPERR_WRONG_CONTROLCHANNEL_HANDLING 0x0009
+#define RSPERR_NOT_FOUND                     0x000a
 
 /* Implementation-specific error causes */
 #define RSPERR_NOT_INITIALIZED               0x1000
@@ -56,6 +57,7 @@ extern "C" {
 #define RSPERR_CONNECTION_FAILURE_CONNECT    0x1006
 #define RSPERR_NO_REGISTRAR                  0x1007
 #define RSPERR_TIMEOUT                       0x1008
+#define RSPERR_UNRECOGNIZED_PARAMETER_SILENT 0x1009
 
 /* Handlespace-management specific error causes */
 #define RSPERR_NO_RESOURCES                  0xf002
