@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpoolsocket.c 1142 2006-05-24 13:17:42Z dreibh $
+ * $Id: rserpoolsocket.c 1336 2007-02-13 14:08:22Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,7 +75,7 @@ struct RSerPoolSocket* getRSerPoolSocketForDescriptor(int sd)
    if(rserpoolSocket == NULL) {
       LOG_ERROR
       fprintf(stdlog, "Bad RSerPool socket descriptor %d\n", sd);
-      LOG_END
+      LOG_END_FATAL
    }
    return(rserpoolSocket);
 }
@@ -312,9 +312,10 @@ bool doRegistration(struct RSerPoolSocket* rserpoolSocket,
       fprintf(stdlog, "(Re-)Registration successful, ID is $%08x\n",
               rserpoolSocket->PoolElement->Identifier);
       LOG_END
-
+/*
       printf("(Re-)Registration successful, ID is $%08x\n",
              rserpoolSocket->PoolElement->Identifier);
+*/
    }
    else {
       LOG_ERROR
