@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rspbasicmode.c 1183 2006-08-10 09:46:18Z dreibh $
+ * $Id: rspbasicmode.c 1335 2007-02-13 12:32:36Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,13 +58,13 @@ static bool addStaticRegistrars(struct RegistrarTable* registrarTable,
                                 struct rsp_info*       info);
 #ifdef ENABLE_CSP
 static size_t getComponentStatus(void*                         userData,
-                                 unsigned long long*           identifier,
+                                 uint64_t*                     identifier,
                                  struct ComponentAssociation** caeArray,
                                  char*                         statusText,
                                  char*                         componentAddress,
                                  double*                       workload);
 extern size_t getSessionStatus(struct ComponentAssociation** caeArray,
-                               unsigned long long*           identifier,
+                               uint64_t*                     identifier,
                                char*                         statusText,
                                char*                         componentAddress,
                                double*                       workload,
@@ -79,6 +79,14 @@ int rsp_initialize(struct rsp_info* info)
 {
    static const char* buildDate = __DATE__;
    static const char* buildTime = __TIME__;
+   struct rsp_info    emptyinfo;
+
+   beginLogging();
+
+   if(info == NULL) {
+      memset(&emptyinfo, 0, sizeof(emptyinfo));
+      info = &emptyinfo;
+   }
 
    /* ====== Check for problems ========================================== */
    if(gAsapInstance != NULL) {
@@ -92,7 +100,10 @@ int rsp_initialize(struct rsp_info* info)
    threadSafetyNew(&gThreadSafety, "RsplibInstance");
    threadSafetyNew(&gRSerPoolSocketSetMutex, "gRSerPoolSocketSet");
    dispatcherNew(&gDispatcher, lock, unlock, NULL);
-   gAsapInstance = asapInstanceNew(&gDispatcher, (union sockaddr_union*)info->ri_registrar_announce, NULL);
+   gAsapInstance = asapInstanceNew(&gDispatcher,
+                                   (info->ri_disable_autoconfig == 0),
+                                   (union sockaddr_union*)info->ri_registrar_announce,
+                                   NULL);
    if(gAsapInstance) {
       if(info) {
          info->ri_version    = RSPLIB_VERSION;
@@ -119,8 +130,8 @@ int rsp_initialize(struct rsp_info* info)
 
       /* ====== Initialize session storage =============================== */
       simpleRedBlackTreeNew(&gRSerPoolSocketSet,
-                                rserpoolSocketPrint,
-                                rserpoolSocketComparison);
+                            rserpoolSocketPrint,
+                            rserpoolSocketComparison);
 
       /* ====== Initialize RSerPool Socket descriptor storage ============ */
       simpleRedBlackTreeNew(&gRSerPoolSocketSet, rserpoolSocketPrint, rserpoolSocketComparison);
@@ -134,7 +145,7 @@ int rsp_initialize(struct rsp_info* info)
 
          /* ====== Add static registrars ================================= */
          if( (info == NULL) ||
-	     (addStaticRegistrars(gAsapInstance->RegistrarSet, info)) ) {
+             (addStaticRegistrars(gAsapInstance->RegistrarSet, info)) ) {
             LOG_NOTE
             fputs("rsplib is ready\n", stdlog);
             LOG_END
@@ -207,6 +218,7 @@ void rsp_cleanup()
       threadSafetyDelete(&gRSerPoolSocketSetMutex);
       threadSafetyDelete(&gThreadSafety);
    }
+   finishLogging();
 }
 
 
@@ -562,7 +574,7 @@ unsigned int rsp_getpolicybyname(const char* policyName)
 #ifdef ENABLE_CSP
 /* ###### Get PE/PU status ############################################### */
 static size_t getComponentStatus(void*                         userData,
-                                 unsigned long long*           identifier,
+                                 uint64_t*                     identifier,
                                  struct ComponentAssociation** caeArray,
                                  char*                         statusText,
                                  char*                         componentAddress,
