@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rspenhancedmode.c 1181 2006-08-04 02:19:39Z dreibh $
+ * $Id: rspenhancedmode.c 1335 2007-02-13 12:32:36Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1292,14 +1292,14 @@ ssize_t rsp_recvmsg(int                    sd,
           (messageBufferHasPartial(rserpoolSocket->MsgBuffer)) &&
           (ntohl(rinfo->rinfo_ppid) != PPID_ASAP) ) {
          if(buffer != NULL) {
-            if((ssize_t)bufferLength < rserpoolSocket->MsgBuffer->BufferPos) {
+            if(bufferLength < rserpoolSocket->MsgBuffer->BufferPos) {
                LOG_ERROR
                fputs("Buffer is too small to keep even partial message\n", stdlog);
                LOG_END
                errno = ENOMEM;
                return(-1);
             }
-            received = min(rserpoolSocket->MsgBuffer->BufferPos, (ssize_t)bufferLength);
+            received = min(rserpoolSocket->MsgBuffer->BufferPos, bufferLength);
             memcpy(buffer, rserpoolSocket->MsgBuffer->Buffer, received);
          }
          messageBufferReset(rserpoolSocket->MsgBuffer);
@@ -1507,7 +1507,7 @@ int rsp_csp_setstatus(int                sd,
 #ifdef ENABLE_CSP
 /* ###### Get CSP status ################################################# */
 size_t getSessionStatus(struct ComponentAssociation** caeArray,
-                        unsigned long long*           identifier,
+                        uint64_t*                     identifier,
                         char*                         statusText,
                         char*                         componentLocation,
                         double*                       workload,
@@ -1579,7 +1579,7 @@ size_t getSessionStatus(struct ComponentAssociation** caeArray,
                *identifier = CID_COMPOUND(CID_GROUP_POOLELEMENT, rserpoolSocket->PoolElement->Identifier);
             }
             if(PPT_IS_ADAPTIVE(rserpoolSocket->PoolElement->LoadInfo.rli_policy)) {
-               *workload = rserpoolSocket->PoolElement->LoadInfo.rli_load / (double)0xffffff;
+               *workload = rserpoolSocket->PoolElement->LoadInfo.rli_load / (double)PPV_MAX_LOAD;
             }
          }
          rserpoolSocket = (struct RSerPoolSocket*)simpleRedBlackTreeGetNext(&gRSerPoolSocketSet, &rserpoolSocket->Node);
