@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: server.cc 1175 2006-08-03 00:27:08Z dreibh $
+ * $Id: server.cc 1288 2007-01-11 20:07:41Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,14 +24,15 @@
  */
 
 #include "rserpool.h"
-#include "loglevel.h"
 #include "breakdetector.h"
 #include "tagitem.h"
-#include "rsputilities.h"
 #include "netutilities.h"
 #include "standardservices.h"
 #include "fractalgeneratorservice.h"
 #include "calcappservice.h"
+#ifdef ENABLE_CSP
+#include "componentstatuspackets.h"
+#endif
 
 
 #define SERVICE_ECHO     1
@@ -46,18 +47,18 @@
 /* ###### Main program ################################################### */
 int main(int argc, char** argv)
 {
-   struct rsp_info      info;
-   struct rsp_loadinfo  loadInfo;
-   union sockaddr_union asapAnnounceAddress;
-   double               degradation;
-   unsigned int         reregInterval = 30000;
-   unsigned int         runtimeLimit  = 0;
-   unsigned int         service       = SERVICE_ECHO;
-   const char*          poolHandle    = NULL;
-   struct TagItem       tags[8];
+   struct rsp_info     info;
+   struct rsp_loadinfo loadInfo;
+   struct TagItem      tags[8];
+   double              degradation;
+   unsigned int        identifier;
+   unsigned int        reregInterval = 30000;
+   unsigned int        runtimeLimit  = 0;
+   unsigned int        service       = SERVICE_ECHO;
+   const char*         poolHandle    = NULL;
 
    /* ====== Read parameters ============================================= */
-   memset(&info, 0, sizeof(info));
+   rsp_initinfo(&info);
    tags[0].Tag  = TAG_PoolElement_Identifier;
    tags[0].Data = 0;
    tags[1].Tag  = TAG_DONE;
@@ -67,37 +68,21 @@ int main(int argc, char** argv)
    memset(&loadInfo, 0, sizeof(loadInfo));
    loadInfo.rli_policy = PPT_ROUNDROBIN;
    for(int i = 1;i < argc;i++) {
-      if(!(strncmp(argv[i], "-log" ,4))) {
-         if(initLogging(argv[i]) == false) {
-            exit(1);
-         }
+      if(rsp_initarg(&info, argv[i])) {
+         /* rsplib argument */
       }
-#ifdef ENABLE_CSP
-      if(!(strncmp(argv[i], "-csp" ,4))) {
-         if(initComponentStatusReporter(&info, argv[i]) == false) {
-            exit(1);
+      if(!(strncmp(argv[i], "-identifier=", 12))) {
+         if(sscanf((const char*)&argv[i][12], "0x%x", &identifier) == 0) {
+            if(sscanf((const char*)&argv[i][12], "%u", &identifier) == 0) {
+               fputs("ERROR: Bad registrar ID given!\n", stderr);
+               exit(1);
+            }
          }
-      }
-#endif
-      else if(!(strncmp(argv[i], "-identifier=", 12))) {
-         tags[0].Data = atol((const char*)&argv[i][12]);
+         tags[0].Data = identifier;
 #ifdef ENABLE_CSP
          info.ri_csp_identifier = CID_COMPOUND(CID_GROUP_POOLELEMENT, tags[0].Data);
 #endif
       }
-      else if(!(strncmp(argv[i], "-registrar=", 11))) {
-         if(addStaticRegistrar(&info, (char*)&argv[i][11]) < 0) {
-            fprintf(stderr, "ERROR: Bad registrar setting %s\n", argv[i]);
-            exit(1);
-         }
-      }
-      else if(!(strncmp(argv[i], "-asapannounce=", 14))) {
-         if(string2address((char*)&argv[i][14], &asapAnnounceAddress) == false) {
-            fprintf(stderr, "ERROR: Bad ASAP announce setting %s\n", argv[i]);
-            exit(1);
-         }
-         info.ri_registrar_announce = (struct sockaddr*)&asapAnnounceAddress;
-      }
       else if(!(strncmp(argv[i], "-poolhandle=" ,12))) {
          poolHandle = (char*)&argv[i][12];
       }
@@ -123,24 +108,24 @@ int main(int argc, char** argv)
             loadInfo.rli_policy = PPT_RANDOMIZED_LEASTUSED;
          }
          else if(sscanf((const char*)&argv[i][8], "LeastUsedDegradation:%lf", &degradation) == 1) {
-            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)0xffffff);
+            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
             if(loadInfo.rli_load_degradation < 0) {
                fputs("ERROR: Bad LUD degradation value!\n", stderr);
                exit(1);
             }
-            else if(loadInfo.rli_load_degradation > 0xffffff) {
+            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LUD degradation value!\n", stderr);
                exit(1);
             }
             loadInfo.rli_policy = PPT_LEASTUSED_DEGRADATION;
          }
          else if(sscanf((const char*)&argv[i][8], "PriorityLeastUsed:%lf", &degradation) == 1) {
-            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)0xffffff);
+            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
             if(loadInfo.rli_load_degradation < 0) {
                fputs("ERROR: Bad PLU degradation value!\n", stderr);
                exit(1);
             }
-            else if(loadInfo.rli_load_degradation > 0xffffff) {
+            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad PLU degradation value!\n", stderr);
                exit(1);
             }
@@ -154,7 +139,7 @@ int main(int argc, char** argv)
                fputs("ERROR: Bad LU-DPF DPF value!\n", stderr);
                exit(1);
             }
-            loadInfo.rli_load_dpf = (unsigned int)rint(dpf * (double)0xffffffff);
+            loadInfo.rli_load_dpf = (unsigned int)rint(dpf * (double)PPV_MAX_LOADDPF);
             loadInfo.rli_policy = PPT_LEASTUSED_DPF;
          }
          else if(sscanf((const char*)&argv[i][8], "LeastUsedDegradationDPF:%lf:%lf", &degradation, &dpf) == 2) {
@@ -162,13 +147,13 @@ int main(int argc, char** argv)
                fputs("ERROR: Bad LU-DPF DPF value!\n", stderr);
                exit(1);
             }
-            loadInfo.rli_load_dpf         = (unsigned int)rint(dpf * (double)0xffffffff);
-            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)0xffffff);
+            loadInfo.rli_load_dpf         = (unsigned int)rint(dpf * (double)PPV_MAX_LOADDPF);
+            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
             if(loadInfo.rli_load_degradation < 0) {
                fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
                exit(1);
             }
-            else if(loadInfo.rli_load_degradation > 0xffffff) {
+            else if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
                fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
                exit(1);
             }
@@ -185,7 +170,7 @@ int main(int argc, char** argv)
                fputs("ERROR: Bad WRAND-DPF DPF value!\n", stderr);
                exit(1);
             }
-            loadInfo.rli_weight_dpf = (unsigned int)rint(dpf * (double)0xffffffff);
+            loadInfo.rli_weight_dpf = (unsigned int)rint(dpf * (double)PPV_MAX_WEIGHTDPF);
             loadInfo.rli_policy = PPT_WEIGHTED_RANDOM_DPF;
          }
          else {
@@ -398,5 +383,6 @@ int main(int argc, char** argv)
                                 (struct TagItem*)&tags);
    }
 
+   rsp_freeinfo(&info);
    return(0);
 }
