@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: takeoverprocess.h 975 2006-03-01 21:11:38Z dreibh $
+ * $Id: takeoverprocess.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,25 +34,19 @@ extern "C" {
 
 struct TakeoverProcess
 {
-   struct STN_CLASSNAME    IndexStorageNode;
-   struct STN_CLASSNAME    TimerStorageNode;
-
-   RegistrarIdentifierType TargetID;
-   unsigned long long      ExpiryTimeStamp;
-
    size_t                  OutstandingAcknowledgements;
    RegistrarIdentifierType PeerIDArray[0];
 };
 
 
-struct TakeoverProcess* getTakeoverProcessFromIndexStorageNode(struct STN_CLASSNAME* node);
-struct TakeoverProcess* getTakeoverProcessFromTimerStorageNode(struct STN_CLASSNAME* node);
-void takeoverProcessIndexPrint(const void* takeoverProcessPtr,
-                               FILE*       fd);
-int takeoverProcessIndexComparison(const void* takeoverProcessPtr1,
-                                   const void* takeoverProcessPtr2);
-int takeoverProcessTimerComparison(const void* takeoverProcessPtr1,
-                                   const void* takeoverProcessPtr2);
+struct TakeoverProcess* takeoverProcessNew(
+                           const RegistrarIdentifierType        targetID,
+                           struct ST_CLASS(PeerListManagement)* peerList);
+void takeoverProcessDelete(struct TakeoverProcess* takeoverProcess);
+
+size_t takeoverProcessAcknowledge(struct TakeoverProcess*       takeoverProcess,
+                                  const RegistrarIdentifierType targetID,
+                                  const RegistrarIdentifierType acknowledgerID);
 
 
 #ifdef __cplusplus
